#[repr(u8)]pub enum Ndpageend {
NDPAGEEND_0 = 0,
NDPAGEEND_1 = 1,
}Variants
NDPAGEEND_0 = 0
The last address of main space in the NAND is not written by AXI command.
NDPAGEEND_1 = 1
The last address of main space in the NAND is written by AXI command.
Implementations